@@ -88,18 +88,20 @@ and3s <- function(exprA, exprB = NULL, exprC = NULL,
       xx2 <- exprB
     }
   }
-  switch(oo1,
-         "%in%" = {
-           xx1 <- finp(xx1, yy1, nThread = nThread, .raw = 1L)
-           yy1 <- NULL
-           oo1 <- "=="
-         },
-         "%notin%" = {
-           xx1 <- fnotinp(xx1, yy1, nThread = nThread, .raw = 1L)
-           yy1 <- NULL
-           oo1 <- "=="
-         })
-  if (is.character(oo2)) {
+  if (!is.raw(xx1)) {
+    switch(oo1,
+           "%in%" = {
+             xx1 <- finp(xx1, yy1, nThread = nThread, .raw = 1L)
+             yy1 <- NULL
+             oo1 <- "=="
+           },
+           "%notin%" = {
+             xx1 <- fnotinp(xx1, yy1, nThread = nThread, .raw = 1L)
+             yy1 <- NULL
+             oo1 <- "=="
+           })
+  }
+  if (is.character(oo2) && !is.raw(xx2)) {
     switch(oo2,
            "%in%" = {
              xx2 <- finp(xx2, yy2, nThread = nThread, .raw = 1L)
@@ -207,6 +209,7 @@ or3s <- function(exprA, exprB = NULL, exprC = NULL,
       xx2 <- exprB
     }
   }
+
   switch(oo1,
          "%in%" = {
            xx1 <- finp(xx1, yy1, nThread = nThread)
@@ -218,6 +221,7 @@ or3s <- function(exprA, exprB = NULL, exprC = NULL,
            yy1 <- NULL
            oo1 <- "=="
          })
+
   if (is.character(oo2)) {
     switch(oo2,
            "%in%" = {
